@@ -6,18 +6,25 @@ import requests
 URL = "https://ewib.nbp.pl/plewibnra?dokNazwa=plewibnra.txt"
 
 
+bic_remapping = {
+    "PLUPLPRXXX": "POLUPLPRXXX",
+    "POLUPLPRXX": "POLUPLPRXXX",
+}
+
+
 def process():
     registry = []
     with requests.get(URL, stream=True) as fp:
         for row in fp.iter_lines():
-            cells = [cell.strip() for cell in row.decode("latin1").split("\t")]
+            cells = [cell.strip() for cell in row.decode("CP852").split("\t")]
             if len(cells) != 32:
                 continue
+            bic = cells[19].upper()
             registry.append(
                 {
                     "country_code": "PL",
                     "primary": True,
-                    "bic": cells[19].upper(),
+                    "bic": bic_remapping.get(bic, bic),
                     "bank_code": cells[4],
                     "name": cells[1],
                     "short_name": cells[1],
